#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'WWW::Comic::Plugin::Wulffmorgenthaler' );
}

diag( "Testing WWW::Comic::Plugin::Wulffmorgenthaler $WWW::Comic::Plugin::Wulffmorgenthaler::VERSION, Perl $], $^X" );
